#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

import htf.core  # noqa: F401: needed for license unlocking
from .__version__ import __version_info__, __version__
from .settings import Settings, SettingsNoSingleton
from .thread import Thread
from .report import DOORSTestReport
from .markers import (
    MetaData,
    Id,
    Revision,
    Rev,
    LastChangedBy,
    LastChangedDate,
    LastChangedRevision,
    URL,
    RCSfile,
    RCSFile,
    Date,
    Header,
    Author,
    Source,
    HeadURL,
    TestingframeworkVersion,
)
from .decorators import (
    test,
    periodic,
    enqueue_exception,
    timed,
    raises,
    skip_if,
    meets_doors_requirements,
    stacktrace,
    before,
    after,
    skip,
    requirements,
)
from .tags_decorator import tags
from .metadata_decorator import metadata
from .testcase import TestCase
from .fixtures import fixture
from .main import main, run, dryrun, get_tags, get_statements, module_list, verify

from .exceptions import SkipTest, SkipStep, ParsingError, ThreadExit

from .suite import TestSuite

from .retry import retry, retry_sync, retriable, retrying

from htf.util.data_driven_testing import (
    data,
    product,
    permutations,
    combinations,
    combinations_with_replacement,
    JSONFileIterator,
    json_data,
    YAMLFileIterator,
    yaml_data,
    CSVFileIterator,
    csv_data,
)

from htf.assertions import (
    set_equality_asserter,
    get_equality_asserter,
    assert_true,
    assert_false,
    assert_equal,
    assert_dict_equal,
    assert_set_equal,
    assert_sequence_equal,
    assert_list_equal,
    assert_tuple_equal,
    assert_multi_line_equal,
    assert_str_equal,
    assert_not_equal,
    assert_almost_equal,
    assert_not_almost_equal,
    assert_raises,
    assert_raises_regex,
    assert_in,
    assert_not_in,
    assert_less,
    assert_less_equal,
    assert_greater,
    assert_greater_equal,
    assert_is,
    assert_is_not,
    assert_is_none,
    assert_is_not_none,
    assert_is_instance,
    assert_not_is_instance,
    assert_is_not_instance,
    assert_regex,
    assert_not_regex,
    set_diff_threshold,
    set_repr_length,
)

from htf.interaction.validators import regex_validator, int_validator, float_validator

from htf.gherkin.decorators import feature, scenario, given, when, then, transformation, data_generator

from .environment import get_fixture, get_fixture_sync

__all__ = [
    "__version_info__",
    "__version__",
    "TestCase",
    "fixture",
    "Settings",
    "SettingsNoSingleton",
    "DOORSTestReport",
    "MetaData",
    "Id",
    "Revision",
    "Rev",
    "LastChangedBy",
    "LastChangedRevision",
    "RCSFile",
    "RCSfile",
    "URL",
    "LastChangedDate",
    "Date",
    "Header",
    "Author",
    "Source",
    "HeadURL",
    "TestingframeworkVersion",
    "Thread",
    "periodic",
    "enqueue_exception",
    "timed",
    "raises",
    "meets_doors_requirements",
    "stacktrace",
    "before",
    "after",
    "requirements",
    "TestSuite",
    "skip",
    "skip_if",
    "SkipTest",
    "SkipStep",
    "tags",
    "metadata",
    "test",
    "ParsingError",
    "ThreadExit",
    "retry",
    "retry_sync",
    "retriable",
    "retrying",
    "data",
    "product",
    "permutations",
    "combinations",
    "combinations_with_replacement",
    "JSONFileIterator",
    "json_data",
    "YAMLFileIterator",
    "yaml_data",
    "CSVFileIterator",
    "csv_data",
    "main",
    "run",
    "dryrun",
    "get_tags",
    "get_statements",
    "module_list",
    "set_equality_asserter",
    "get_equality_asserter",
    "verify",
    "assert_true",
    "assert_false",
    "assert_equal",
    "assert_dict_equal",
    "assert_multi_line_equal",
    "assert_str_equal",
    "assert_set_equal",
    "assert_sequence_equal",
    "assert_list_equal",
    "assert_tuple_equal",
    "assert_not_equal",
    "assert_almost_equal",
    "assert_not_almost_equal",
    "assert_raises",
    "assert_raises_regex",
    "assert_in",
    "assert_not_in",
    "assert_less",
    "assert_less_equal",
    "assert_greater",
    "assert_greater_equal",
    "assert_is",
    "assert_is_not",
    "assert_is_none",
    "assert_is_not_none",
    "assert_is_instance",
    "assert_not_is_instance",
    "assert_is_not_instance",
    "assert_regex",
    "assert_not_regex",
    "set_diff_threshold",
    "set_repr_length",
    "regex_validator",
    "int_validator",
    "float_validator",
    "feature",
    "scenario",
    "given",
    "when",
    "then",
    "transformation",
    "data_generator",
    "get_fixture",
    "get_fixture_sync",
]
