#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import List, Optional

from htf.gherkin.scenario import Scenario
from htf.gherkin.scenario_outline import ScenarioOutline
from htf.gherkin.step import Step


class Feature:
    def __init__(
        self,
        name: str,
        doc: str,
        filename: str,
        line_number: int,
    ) -> None:
        self.name = name
        self.doc = doc
        self.filename = filename
        self.line_number = line_number
        self.scenarios: List[Scenario] = []
        self.scenario_outlines: List[ScenarioOutline] = []
        self.background: List[Step] = []  # list of given preconditions stated in Background:
        self.tags: Optional[List[str]] = None
        self.requirements: Optional[List[str]] = None
        self.skip_reason: Optional[str] = None

    def add_scenario(self, scenario: Scenario) -> None:
        self.scenarios.append(scenario)

    def add_scenario_outline(self, scenario_outline: ScenarioOutline) -> None:
        self.scenario_outlines.append(scenario_outline)

    def set_background(self, background: List[Step]) -> None:
        self.background = background

    def set_tags(self, tags: List[str]) -> None:
        self.tags = tags

    def set_requirements(self, requirements: List[str]) -> None:
        self.requirements = requirements

    def set_skipped(self, reason: str) -> None:
        self.skip_reason = reason
