#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Optional, Tuple, Any, Dict, List


class Scenario:
    def __init__(
        self,
        name: str,
        doc: str,
        filename: str,
        line_number: int,
        args: Optional[Tuple[Any]] = None,
        kwargs: Optional[Dict[str, Any]] = None,
    ) -> None:
        self.name = name
        self.doc = doc
        self.rule = ""
        self.filename = filename
        self.line_number = line_number
        self.given_preconditions: List["Step"] = list()  # type: ignore  # noqa: F821
        self.when_conditions: List["Step"] = list()  # type: ignore  # noqa: F821
        self.then_assertions: List["Step"] = list()  # type: ignore  # noqa: F821

        # Optional parameters for data driven testing
        self.args = args
        self.kwargs = kwargs

        # Tags, requirements and skip reasons
        self.tags: Optional[List[str]] = None
        self.requirements: Optional[List[str]] = None
        self.skip_reason: Optional[str] = None

    def add_given(self, step: "Step") -> None:  # type: ignore  # noqa: F821
        self.given_preconditions.append(step)

    def add_when(self, step: "Step") -> None:  # type: ignore  # noqa: F821
        self.when_conditions.append(step)

    def add_then(self, step: "Step") -> None:  # type: ignore  # noqa: F821
        self.then_assertions.append(step)

    def set_tags(self, tags: List[str]) -> None:
        self.tags = tags

    def set_requirements(self, requirements: List[str]) -> None:
        self.requirements = requirements

    def set_skipped(self, reason: str) -> None:
        self.skip_reason = reason
