#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Any, Dict, Optional
import copy

from htf.gherkin.context import Context


class Step:
    def __init__(
        self,
        expression: str,
        line: str,
        filename: str,
        line_number: int,
    ) -> None:
        self.expression = expression
        self.line = line
        self.filename = filename
        self.line_number = line_number
        self.context: Optional[Context] = None

    def set_context(self, context: Context) -> None:
        """
        Set the context of step , to be passed and used in test function. Context can contain text or table
        Args:
            context: context object of step text and step table
        """
        self.context = context

    def __str__(self) -> str:  # pragma: no cover
        return "<Step expression='{}'>".format(self.expression)

    __repr__ = __str__  # pragma: no cover

    def replace(self, replacements: Dict[str, Any], filename: str) -> "Step":
        """
        Replace replacements in ``expression`` and ``line`` and return a deep-copy.

        Args:
            replacements: dictionary of replacements
            filename: the data source filename

        Returns:
            deep copy with replacements
        """

        if not isinstance(replacements, dict):  # pragma: no cover
            raise ValueError("Data sources must be of type dict in file {}".format(filename))

        copied_step = copy.deepcopy(self)

        for key, value in replacements.items():
            copied_step.line = copied_step.line.replace(r"<{}>".format(key), str(value))
            copied_step.expression = copied_step.expression.replace(r"<{}>".format(key), str(value))

        return copied_step
