#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Optional, Callable, Any
import re


def regex_validator(pattern: str, exception_message: Optional[str] = None) -> Callable[[str], str]:
    """
    A regex validator factory.

    Args:
        pattern: the regex pattern to be checked
        exception_message=None: the optional exception message supplied to the user in its browser

    Returns:
        an interaction validator for pattern
    """

    def validator(text: str) -> str:
        if not re.match(pattern, text):
            if exception_message is not None:
                raise Exception(exception_message)
            else:
                raise Exception("Input does not match required pattern '{}'".format(pattern))
        return text

    return validator


def int_validator(value: Any) -> int:
    """
    An int validator for interactive tests.
    """
    try:
        return int(value)
    except Exception:
        raise Exception("Input must be an integer value.")


def float_validator(value: Any) -> float:
    """
    A float validator for interactive tests.
    """
    try:
        return float(value)
    except Exception:
        raise Exception("Input must be a float value.")
