#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from typing import Optional, List, Union, Any, Dict

import htf.core
from htf.core import dryrun as _dryrun
from htf.core import get_choices as _get_choices
from htf.core import get_tags as _get_tags
from htf.core import get_statements as _get_statements
from htf.core import main as _main
from htf.core import module_list as _module_list
from htf.core import run as _run


def dryrun(
    title: str = "Testreport",
    tests: Union[Any, List[Any]] = "__main__",
    tags: Optional[str] = None,
    fixture_tags: Optional[str] = None,
    html_report: Optional[Union[str, List[str]]] = None,
    junit_xml_report: Optional[Union[str, List[str]]] = None,
    json_report: Optional[Union[str, List[str]]] = None,
    yaml_report: Optional[Union[str, List[str]]] = None,
    report_server: Optional[Union[str, List[str]]] = None,
    extra_report: Optional[Union[Any, List[Any]]] = None,
    create_drafts: bool = False,
    open_report: bool = False,
    pattern: str = "test*.py",
    metadata: Optional[Dict[str, Any]] = None,
    parameters: Optional[Dict[str, str]] = None,
    exit: bool = True,
    fail_fast: bool = False,
    minimize_report_size: bool = False,
    interactive: bool = False,
    interactive_address: str = "0.0.0.0",
    interactive_port: int = 8080,
    open_browser: bool = True,
    shuffle: bool = False,
    shuffle_seed: Optional[Union[str, int]] = None,
) -> int:
    """
    Test runner for a dry run to watch the test suite.

    Args:
        title: the test's title
        tests=None: a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        ags=None: test filter expression
        fixture_tags=None: fixture filter expression
        html_report=None: HTML-report filename(s)
        junit_xml_report=None: JUnit-XML-report
            filename(s)
        json_report=None: JSON-report
            filename(s)
        yaml_report=None: YAML-report
            filename(s)
        report_server=None: Url or list of urls to report server
        extra_report=None: Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        create_drafts=False: if set to ``True`` draft reports are created after each test
        open_report=False: if set to ``True`` the HTML test report is opened after the test run
        pattern="test*.py": the pattern to be used when searching for
            python files in folders
        metadata=None: a dictionary that contains metadata about the test run
        parameters=None: a dictionary that contains parameters for the test run
        exit=True: if set to ``True`` the exit() is called at the
            end of the tests
        fail_fast=False: if set to ``True`` the test run ends after
            the first failing test
        minimize_report_size=False: if set to ``True`` the report size is minimized.
        interactive=False: if set to ``True`` the tests are run interactively
        interactive_address="0.0.0.0": the ip address the interaction server listens on.
        interactive_port=8080: the port the interaction server listens on.
        open_browser=True: if set to ``False`` browser is not opened automatically
        shuffle=False: set to ``True`` to shuffle tests
        shuffle_seed=None: the shuffle seed or 'last' to use the last shuffle seed

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _dryrun(
        title=title,
        tests=tests,
        tags=tags,
        fixture_tags=fixture_tags,
        html_report=html_report,
        junit_xml_report=junit_xml_report,
        json_report=json_report,
        yaml_report=yaml_report,
        report_server=report_server,
        extra_report=extra_report,
        create_drafts=create_drafts,
        open_report=open_report,
        pattern=pattern,
        metadata=metadata,
        parameters=parameters,
        exit=exit,
        fail_fast=fail_fast,
        minimize_report_size=minimize_report_size,
        interactive=interactive,
        interactive_address=interactive_address,
        interactive_port=interactive_port,
        open_browser=open_browser,
        shuffle=shuffle,
        shuffle_seed=shuffle_seed,
    )


def get_choices(part: str) -> List[str]:
    """
    Return a list of strings
    that describe importable python
    modules and its contents.
    Eg.:
    - tests.test_1
    - tests
    - tests.test_1.TestCase
    - tests.test_1.TestCase.test_method

    Case 1) complete or incomplete root module -> list all root
        modules starting with part
    Case 2) complete root module + "." -> list all sub-modules and entries
    Case 3) complete root module + ".<part>" -> list all sub-modules
        and entries starting with part and
    """
    return _get_choices(part=part)


def get_tags(tests: Union[Any, List[Any]] = "__main__", pattern: str = "test*.py") -> List[str]:
    """
    Get a list of tags found in the specified tests.

    Args:
        tests=None: a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        pattern="test*.py": the pattern to be used when searching for
            python files in folders

    Returns:
        list of str: a list of tags found in the specified tests.
    """
    return _get_tags(tests=tests, pattern=pattern)


def verify() -> bool:
    """
    Verify system environment. Needs ``htf-validated`` installed and the license feature ``verification``.

    Returns:
        bool: ``True`` in case the system environment was successfully verified else ``False``
    """
    return htf.core.verify_system_environment(print_errors=True)


def get_statements(tests: Union[Any, List[Any]] = "__main__") -> Dict[str, List[str]]:
    """
    Get a dict of behavior driven development statements found in the specified tests.

    Args:
        tests=None: a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)

    Returns:
        dict: a dict with all behavior driven development statements found
    """
    return _get_statements(tests=tests)


def main(
    title: str = "Testreport",
    tests: Union[Any, List[Any]] = "__main__",
    tags: Optional[str] = None,
    fixture_tags: Optional[str] = None,
    html_report: Optional[Union[str, List[str]]] = None,
    junit_xml_report: Optional[Union[str, List[str]]] = None,
    json_report: Optional[Union[str, List[str]]] = None,
    yaml_report: Optional[Union[str, List[str]]] = None,
    report_server: Optional[Union[str, List[str]]] = None,
    extra_report: Optional[Union[Any, List[Any]]] = None,
    create_drafts: bool = False,
    open_report: bool = False,
    pattern: str = "test*.py",
    metadata: Optional[Dict[str, Any]] = None,
    parameters: Optional[Dict[str, str]] = None,
    exit: bool = True,
    fail_fast: bool = False,
    minimize_report_size: bool = False,
    interactive: bool = False,
    interactive_address: str = "0.0.0.0",
    interactive_port: int = 8080,
    open_browser: bool = True,
    shuffle: bool = False,
    shuffle_seed: Optional[Union[str, int]] = None,
) -> int:
    """
    Test runner.

    Args:
        title: the test's title
        tests=None: a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None: test filter expression
        fixture_tags=None: fixture filter expression
        html_report=None: HTML-report filename(s)
        junit_xml_report=None: JUnit-XML-report
            filename(s)
        json_report=None: JSON-report
            filename(s)
        yaml_report=None: YAML-report
            filename(s)
        report_server=None: Url or list of urls to report server
        extra_report=None: Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        create_drafts=False: if set to ``True`` draft reports are created after each test
        open_report=False: if set to ``True`` the HTML test report is opened after the test run
        pattern="test*.py": the pattern to be used when searching for
            python files in folders
        metadata=None: a dictionary that contains metadata about the test run
        parameters=None: a dictionary that contains parameters for the test run
        exit=True: if set to ``True`` the exit() is called at the
            end of the tests
        fail_fast=False: if set to ``True`` the test run ends after
            the first failing test
        minimize_report_size=False: if set to ``True`` the report size is minimized.
        interactive=False: if set to ``True`` the tests are run interactively
        interactive_address="0.0.0.0": the ip address the interaction server listens on.
        interactive_port=8080: the port the interaction server listens on.
        open_browser=True: if set to ``False`` browser is not opened automatically
        shuffle=False: set to ``True`` to shuffle tests
        shuffle_seed=None: the shuffle seed or 'last' to use the last shuffle seed

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _main(
        title=title,
        tests=tests,
        tags=tags,
        fixture_tags=fixture_tags,
        html_report=html_report,
        junit_xml_report=junit_xml_report,
        json_report=json_report,
        yaml_report=yaml_report,
        report_server=report_server,
        extra_report=extra_report,
        create_drafts=create_drafts,
        open_report=open_report,
        pattern=pattern,
        metadata=metadata,
        parameters=parameters,
        exit=exit,
        fail_fast=fail_fast,
        minimize_report_size=minimize_report_size,
        interactive=interactive,
        interactive_address=interactive_address,
        interactive_port=interactive_port,
        open_browser=open_browser,
        shuffle=shuffle,
        shuffle_seed=shuffle_seed,
    )


def module_list(path: str) -> List[str]:
    """
    Return the list containing the names of the modules available in the given
    folder.
    """
    return _module_list(path=path)


def run(
    title: str = "Testreport",
    tests: Union[Any, List[Any]] = "__main__",
    tags: Optional[str] = None,
    fixture_tags: Optional[str] = None,
    html_report: Optional[Union[str, List[str]]] = None,
    junit_xml_report: Optional[Union[str, List[str]]] = None,
    json_report: Optional[Union[str, List[str]]] = None,
    yaml_report: Optional[Union[str, List[str]]] = None,
    report_server: Optional[Union[str, List[str]]] = None,
    extra_report: Optional[Union[Any, List[Any]]] = None,
    create_drafts: bool = False,
    open_report: bool = False,
    pattern: str = "test*.py",
    metadata: Optional[Dict[str, Any]] = None,
    parameters: Optional[Dict[str, str]] = None,
    exit: bool = True,
    fail_fast: bool = False,
    minimize_report_size: bool = False,
    interactive: bool = False,
    interactive_address: str = "0.0.0.0",
    interactive_port: int = 8080,
    open_browser: bool = True,
    shuffle: bool = False,
    shuffle_seed: Optional[Union[str, int]] = None,
) -> int:
    """
    Test runner.

    Args:
        title: the test's title
        tests=None: a
            test-specifier or a list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None: test filter expression
        fixture_tags=None: fixture filter expression
        html_report=None: HTML-report filename(s)
        junit_xml_report=None: JUnit-XML-report
            filename(s)
        json_report=None: JSON-report
            filename(s)
        yaml_report=None: YAML-report
            filename(s)
        report_server=None: Url or list of urls to report server
        extra_report=None: Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        create_drafts=False: if set to ``True`` draft reports are created after each test
        open_report=False: if set to ``True`` the HTML test report is opened after the test run
        pattern="test*.py": the pattern to be used when searching for
            python files in folders
        metadata=None: a dictionary that contains metadata about the test run
        parameters=None: a dictionary that contains parameters for the test run
        exit=True: if set to ``True`` the exit() is called at the
            end of the tests
        fail_fast=False: if set to ``True`` the test run ends after
            the first failing test
        minimize_report_size=False: if set to ``True`` the report size is minimized.
        interactive=False: if set to ``True`` the tests are run interactively
        interactive_address="0.0.0.0": the ip address the interaction server listens on.
        interactive_port=8080: the port the interaction server listens on.
        open_browser=True: if set to ``False`` browser is not opened automatically
        shuffle=False: set to ``True`` to shuffle tests
        shuffle_seed=None: the shuffle seed or 'last' to use the last shuffle seed

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _run(
        title=title,
        tests=tests,
        tags=tags,
        fixture_tags=fixture_tags,
        html_report=html_report,
        junit_xml_report=junit_xml_report,
        json_report=json_report,
        yaml_report=yaml_report,
        report_server=report_server,
        extra_report=extra_report,
        create_drafts=create_drafts,
        open_report=open_report,
        pattern=pattern,
        metadata=metadata,
        parameters=parameters,
        exit=exit,
        fail_fast=fail_fast,
        minimize_report_size=minimize_report_size,
        interactive=interactive,
        interactive_address=interactive_address,
        interactive_port=interactive_port,
        open_browser=open_browser,
        shuffle=shuffle,
        shuffle_seed=shuffle_seed,
    )
