#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Any, Callable

from htf.environment import get_current_environment
from functools import wraps


def metadata(**metadata: Any) -> Callable[..., Any]:
    """
    Provides a way to set metadata in the test report for the decorated function.

    Args:
        metadata: the dictionary of metadata
    """

    def wrapper(wrapped: Callable[..., Any]) -> Callable[..., Any]:
        @wraps(wrapped)
        async def _metadata(*args: Any, **kwargs: Any) -> Any:
            environment = get_current_environment()
            fixture_metadata = await environment.get_fixture("metadata")
            for k, v in metadata.items():
                fixture_metadata.set(k, v)

            wrapped(*args, **kwargs)

        return _metadata

    return wrapper
