#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from typing import Dict, Optional, Any

from htf.report._doors_testreport import DOORSTestReport as _DOORSTestReport


class DOORSTestReport(_DOORSTestReport):
    """
    ``DOORSTestReport`` creates a DOORS test report.
    Links are automatically created from the created DOORS module to the fulfilled requirements.

    To state the fulfilled requirements the :func:`~htf.meets_doors_requirements` decorator should be used.
    """

    def __init__(
        self,
        filename: str,
        report_module: str,
        requirements_modules: Dict[str, str],
        links_modules: Optional[Dict[str, str]] = None,
        render_meta_data: bool = True,
        render_steps: bool = True,
    ) -> None:
        """
        Initialize a ``DOORSTestReport`` instance.

        Args:
            filename: the filename for the DXL test report.
            report_module: the DOORS path to the report module.
            requirements_modules: maps links to DOORS modules.
                The keys are regular expressions and the values are
                the desired target modules.
            links_modules={".*" : "DOORS Links"}: maps requirements to desired link modules.
                The keys are regular expressions and the values are
                the desired link modules.
            render_meta_data=True: if set to `True` metadata is rendered in DOORS
            render_steps=True: if set to `True` steps are rendered in DOORS
        """
        super(DOORSTestReport, self).__init__(
            filename=filename,
            report_module=report_module,
            requirements_modules=requirements_modules,
            links_modules=links_modules,
            render_meta_data=render_meta_data,
            render_steps=render_steps,
        )

    def render(self, data: Dict[str, Any]) -> None:
        """
        Generates and stores a DXL encoded TestReport.

        Args:
            data: test result data
        """
        return super(DOORSTestReport, self).render(data=data)

    def write(self, data: bytes) -> None:
        return super(DOORSTestReport, self).write(data=data)
