#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Optional, List
import argparse
import sys

from htf.core import _ReportToolCore


class ReportTool(_ReportToolCore):
    """
    A tool to extract data from reports.
    """

    def __init__(self, argv: Optional[List[str]] = None) -> None:
        """
        Args:
            argv=None: used for testing, etc.
        """
        self.title = None
        self.html_report = None
        self.junit_xml_report = None
        self.json_report = None
        self.yaml_report = None
        self.report_server = None
        self.reports = None
        self.extract_attachments = None
        self.extract_output = None
        self.open_report = None

        if argv is None:
            argv = sys.argv

        self._parse_arguments(argv)
        self._run()

    def _parse_arguments(self, argv: List[str]) -> None:
        parser = argparse.ArgumentParser(description="report-tool - QABench (HILSTER, https://hilster.io)")

        parser.add_argument("-t", "--title", default=None, help="Output testreport title")
        parser.add_argument(
            "-H", "--html-report", action="append", help="Output HTML report filename (may be repeated)"
        )
        parser.add_argument(
            "-x", "--junit-xml-report", action="append", help="Junit-compatible XML report filename (may be repeated)"
        )
        parser.add_argument(
            "-j", "--json-report", action="append", help="Output JSON report filename (may be repeated)"
        )
        parser.add_argument(
            "-Y", "--yaml-report", action="append", help="Output YAML report filename (may be repeated)"
        )
        parser.add_argument("-r", "--report-server", action="append", help="URL to report server (may be repeated)")
        parser.add_argument(
            "-o",
            "--open-report",
            dest="open_report",
            action="store_true",
            default=False,
            help="Open HTML test report at the end of the test run",
        )

        parser.add_argument(
            "--extract-output",
            action="store_true",
            help="Extract STDOUT and STDERR from each test and store it into a text file.",
        )

        parser.add_argument(
            "--extract-attachments", action="store_true", help="Extract attachments and store them locally."
        )

        parser.add_argument(
            "reports",
            metavar="report",
            nargs="+",
            help="The input test report. All formats are supported. (may be repeated)",
        )

        parser.parse_args(argv[1:], self)

        if (
            self.html_report is None
            and self.junit_xml_report is None
            and self.json_report is None
            and self.yaml_report is None
            and self.report_server is None
        ):
            print("At least one report must be set!")
            parser.print_help()
            exit(1)
