#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from typing import Any, Dict, Optional, Type
from types import TracebackType

from htf.core import TestResult as _TestResult, TestStep, Test


class TestResult(_TestResult):
    """
    A class representing the result of a test.
    """

    def __init__(self, test: Test) -> None:
        """
        Args:
            test: the test this is the result for
        """
        super(TestResult, self).__init__(test=test)

    def attach(self, attachment: Dict[str, Any]) -> None:
        """
        Attach an attachment to the result.

        Args:
            attachment: attachment to add
        """
        return super(TestResult, self).attach(attachment=attachment)

    def attach_bytes(self, title: str, data_bytes: bytes, filename: str, mime_type: str) -> None:
        """
        Accepts bytes and mime type and converts them to a data url and attaches it to the result.

        Args:
            title: the title
            data_bytes: the bytes to attach
            filename: the file name
            mime_type: MIME type of the data bytes
        """
        return super(TestResult, self).attach_bytes(
            title=title, data_bytes=data_bytes, filename=filename, mime_type=mime_type
        )

    def attach_file(self, filename: str, title: str) -> None:
        """
        Attach a file to the current test that is put into
        the test report.

        The attachment size is checked using
        :func:`htf.result.TestResult.get_maximum_attachment_size`.

        Args:
            filename: the filename to be attached
            title: the title
        """
        return super(TestResult, self).attach_file(filename=filename, title=title)

    def attach_file_from_data_url(self, data_url: str, filename: str, mime_type: str) -> None:  # pragma: no cover
        return super(TestResult, self).attach_file_from_data_url(
            data_url=data_url, filename=filename, mime_type=mime_type
        )

    def attach_url(self, url: str, title: str) -> None:
        """
        Attach an url to the current test that is put into the test report.
        This results in an external link and should be used for huge files.

        Args:
            url: the url to be attached
            title: the title
        """
        return super(TestResult, self).attach_url(url=url, title=title)

    def get_maximum_attachment_size(self) -> int:
        """
        Return the maximum attachments size in bytes.

        The default size is 10 Mb.

        Returns:
            int: the maximum attachment size in bytes
        """
        return super(TestResult, self).get_maximum_attachment_size()

    def get_metadata(self, name: str) -> Any:
        """
        Get metadata for name.
        Args:
            name: metadata name

        Returns:
            object: the value
        """
        return super(TestResult, self).get_metadata(name=name)

    def get_stderr(self) -> str:
        """
        Write captured stderr to the results stderr attribute and return it.

        Returns:
            All stderr output captured so far.
        """
        return super(TestResult, self).get_stderr()

    def get_stdout(self) -> str:
        """
        Write captured stdout to the results stdout attribute and return it.

        Returns:
            All stdout output captured so far.
        """
        return super(TestResult, self).get_stdout()

    def set_exception(
        self,
        exc_type: Optional[Type[BaseException]],
        exc_val: Optional[BaseException],
        exc_tb: Optional[TracebackType],
        overwrite: bool = False,
    ) -> None:
        """
        Set the exception responsible for the result.

        Args:
            exc_type: exception type
            exc_val: exception value
            exc_tb: exception traceback
            overwrite: If True, replace the exception if one is set
        """
        return super(TestResult, self).set_exception(
            exc_type=exc_type, exc_val=exc_val, exc_tb=exc_tb, overwrite=overwrite
        )

    def set_maximum_attachment_size(self, size: int) -> None:
        """
        Set the maximum attachment size to ``size`` bytes.

        Args:
            size: the maximum attachment size in bytes.
        """
        return super(TestResult, self).set_maximum_attachment_size(size=size)

    def set_metadata(self, name: str, value: Any) -> None:
        """
        Set a metadata name to a value.

        Args:
            name: metadata name
            value: metadata value
        """
        return super(TestResult, self).set_metadata(name=name, value=value)

    def set_output_capture_enable(self, enabled: bool = True) -> None:
        """
        Toggles output capture.

        Args:
            enabled: If True, any output is captured
        """
        return super(TestResult, self).set_output_capture_enable(enabled=enabled)

    def step(self, title: str, *args: Any, **kwargs: Any) -> TestStep:
        return super(TestResult, self).step(title, *args, **kwargs)

    def to_dict(self) -> Dict[str, Any]:
        """
        Convert the test result to a dictionary.

        Returns:
            A dictionary containing information describing the result.
        """
        return super(TestResult, self).to_dict()
