#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from typing import Optional, Dict, Any, Iterator, List, IO

from htf.core import Settings as _Settings
from htf.core import SettingsNoSingleton as _SettingsNoSingleton


class Settings(_Settings):
    """
    ``Settings`` can be used to access local settings easily.
    It is a singleton.

    The local settings file is automatically searched looking in
    ``$HTF_SETTINGS``, ``$HOME/settings.{txt,json,yml,yaml}`` or ``./settings.{txt,json,yml,yaml}``
    in this order. If no settings file was found an exception is raised except ``create`` is ``True``.

    Settings are stored in JSON or YAML format. If the file extension is ``.yml`` or ``.yaml``
    YAML data is assumed else JSON.
    """

    def __init__(
        self, filename: Optional[str] = None, create: bool = False, defaults: Optional[Dict[str, Any]] = None
    ) -> None:
        """
        Instantiate a Settings instance.

        Args:
            filename=None: the filename to load explicitly
            create=False: if set to ``True`` no exception is raised if no settings are found to create new
                settings
            defaults=None: if set to a dict these values are used as default values before loading the settings
                file
        """
        super(Settings, self).__init__(filename=filename, create=create, defaults=defaults)

    def get(self, key: str, default: Optional[Any] = None) -> Any:
        """
        Get an item and return ``default`` if the item was not found.

        Args:
            key: key for item
            default=None: is returned if ``key`` was not found.

        Returns:
            object: self[key]
        """
        return super(Settings, self).get(key=key, default=default)

    def get_filename(self) -> Optional[str]:
        """
        Return the currently used settings filename.
        """
        return super(Settings, self).get_filename()

    def get_settings_filenames(self) -> List[str]:
        """
        Return a list of possible settings filenames that are tried in order. The first available file is used.
        You can overwrite this method in your specialized ``Settings``.

        Returns:
            list: a list of filenames that are tried to be opened from left to right.
                The first file that is opened will be used to read settings from.
        """
        return super(Settings, self).get_settings_filenames()

    def items(self) -> Iterator[Any]:
        """
        Iterate over items like in a dict.

        Returns:
            Iterator over the items (key, value)
        """
        return super(Settings, self).items()

    def load(self, create: bool = False) -> None:
        return super(Settings, self).load(create=create)

    def open(self, mode: str = "r") -> IO:
        return super(Settings, self).open(mode=mode)

    def save(self) -> None:
        """
        Save current settings to current filename (useful after modification).

        Attention: YAML comments are lost when overwriting an existing YAML file!
        """
        return super(Settings, self).save()

    def update(self, data: Dict[str, Any]) -> None:
        """
        Update settings with ``data``.

        Args:
            data: data to use for update
        """
        return super(Settings, self).update(data=data)


class SettingsNoSingleton(_SettingsNoSingleton):
    """
    Settings without being a singleton.
    """

    def __init__(
        self, filename: Optional[str] = None, create: bool = False, defaults: Optional[Dict[str, Any]] = None
    ) -> None:
        """
        Instantiate a Settings instance.

        Args:
            filename=None: the filename to load explicitly
            create=False: if set to ``True`` no exception is raised if no settings are found to create new
                settings
            defaults=None: if set to a dict these values are used as default values before loading the settings
                file
        """
        super(SettingsNoSingleton, self).__init__(filename=filename, create=create, defaults=defaults)

    def get(self, key: str, default: Optional[Any] = None) -> Any:
        """
        Get an item and return ``default`` if the item was not found.

        Args:
            key: key for item
            default=None: is returned if ``key`` was not found.

        Returns:
            object: self[key]
        """
        return super(SettingsNoSingleton, self).get(key=key, default=default)

    def get_filename(self) -> Optional[str]:
        """
        Return the currently used settings filename.
        """
        return super(SettingsNoSingleton, self).get_filename()

    def get_settings_filenames(self) -> List[str]:
        """
        Return a list of possible settings filenames that are tried in order. The first available file is used.
        You can overwrite this method in your specialized ``Settings``.

        Returns:
            list: a list of filenames that are tried to be opened from left to right.
                The first file that is opened will be used to read settings from.
        """
        return super(SettingsNoSingleton, self).get_settings_filenames()

    def items(self) -> Iterator[Any]:
        """
        Iterate over items like in a dict.

        Returns:
            Iterator over the items (key, value)
        """
        return super(SettingsNoSingleton, self).items()

    def load(self, create: bool = False) -> None:
        return super(SettingsNoSingleton, self).load(create=create)

    def open(self, mode: str = "r") -> IO:
        return super(SettingsNoSingleton, self).open(mode=mode)

    def save(self) -> None:
        """
        Save current settings to current filename (useful after modification).

        Attention: YAML comments are lost when overwriting an existing YAML file!
        """
        return super(SettingsNoSingleton, self).save()

    def update(self, data: Dict[str, Any]) -> None:
        """
        Update settings with ``data``.

        Args:
            data: data to use for update
        """
        return super(SettingsNoSingleton, self).update(data=data)
