#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Callable, Any
import re

_tags_pattern = re.compile(r"^[a-zA-Z0-9_\-\.]+$")


def tags(*tags: str) -> Callable[[Callable[..., Any]], Any]:
    """
    Tag a test or class.

    Args:
        *tags: the tags to be used
    """
    for tag in tags:
        if not _tags_pattern.match(tag):
            raise Exception(r"tag must match regular expression '^[a-zA-Z0-9_\-\.]+$'")

    def tagger(tagged: Callable[..., Any]) -> Callable[..., Any]:
        # tag a method or class
        if not hasattr(tagged, "_htf_tags"):
            tagged._htf_tags = set()  # type: ignore
        tagged._htf_tags = tagged._htf_tags | set(tags)  # type: ignore

        return tagged

    return tagger
