#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

import sys
from htf.termcolors.styles import bold, blue_bold, green_bold, yellow_bold, red_bold, yellow_on_red_bold, grey_bold
import htf.termcolors.styles as styles


def init_termcolors() -> None:
    if sys.platform not in {"win32", "cli"}:  # pragma: no branch
        return

    import colorama

    colorama.init()


init_termcolors()


def info(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for an information.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return bold(text)


def system(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for system message.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return blue_bold(text)


def success(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for a success.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return green_bold(text)


def warning(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for a failure.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return yellow_bold(text)


def failure(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for a failure.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return yellow_bold(text)


def error(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for an error.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return red_bold(text)


def debug(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for a critical error.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return red_bold(text)


def critical(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for a critical error.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return yellow_on_red_bold(text)


def skipped(text: str) -> str:
    """
    Return colored text if supported by terminal using ANSI codes for something skipped.

    Args:
        text: the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return grey_bold(text)


__all__ = ["info", "system", "success", "warning", "failure", "error", "debug", "critical", "skipped"] + [
    func for func in dir(styles)
]
