#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from typing import Callable, Any, Optional, Tuple, Dict, Union, Type, Sequence, List, Set, Iterable

from htf.assertions import _AssertRaisesContext
from htf.core import TestCase as _TestCase, TestStep


class TestCase(_TestCase):
    """
    ``TestCase`` is the basic test case class for the HILSTER Testing Framework
    that should be used with inheritance.
    """

    def __init__(self, method_name: str = "run_test") -> None:
        """
        Args:
            method_name='run_test': the name of the test method to be
                run by the test runner.
        """
        super(TestCase, self).__init__(method_name=method_name)

    @staticmethod
    def assert_almost_equal(
        a: float,
        b: float,
        places: Optional[int] = None,
        delta: Optional[float] = None,
        message: Optional[str] = None,
    ) -> None:
        """
        Assert that ``a`` and ``b`` are almost equal. Useful to compare floating point numbers.
        Comparison is realized either using a maximum ``delta`` or the number of decimal ``places``

        Args:
            a: number
            b: number
            places=None: the number of decimal places for comparison. If ``None`` ``7`` decimal places are used.
            delta=None: the maximum delta
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not almost equal.
        """
        return _TestCase.assert_almost_equal(a=a, b=b, places=places, delta=delta, message=message)

    @staticmethod
    def assert_dict_equal(a: Dict, b: Dict, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are of type ``dict``.

        Args:
            a: a dict
            b: a dict
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_dict_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_equal(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b``. Tries to find a registered equality asserter and uses the base assert if
        no special assert is registered.

        Args:
            a: an object
            b: an object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_false(expression: bool, message: Optional[str] = None) -> None:
        """
        Assert that ``expression`` is ``False``.

        Args:
            expression: the boolean expression to be validated
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``expression`` is not ``False``
        """
        return _TestCase.assert_false(expression=expression, message=message)

    @staticmethod
    def assert_greater(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` is greater than ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not greater than ``b``
        """
        return _TestCase.assert_greater(a=a, b=b, message=message)

    @staticmethod
    def assert_greater_equal(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` is greater or equal to ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not greater or equal to ``b``
        """
        return _TestCase.assert_greater_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_in(member: Any, container: Iterable, message: Optional[str] = None) -> None:
        """
        Assert that ``container`` contains ``member``.

        Args:
            member: the object that shall be included in ``container``
            container: an iterable to search for ``member``
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``member`` is not included in ``container``
        """
        return _TestCase.assert_in(member=member, container=container, message=message)

    @staticmethod
    def assert_is(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``id(a)`` equals ``id(b)``.

        Args:
            a: an object
            b: another object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``id(a)`` does not equal ``id(b)``
        """
        return _TestCase.assert_is(a=a, b=b, message=message)

    @staticmethod
    def assert_is_instance(obj: Any, cls: Type, message: Optional[str] = None) -> None:
        """
        Assert that ``obj`` is an instance of ``cls``.

        Args:
            obj: an instance
            cls: a class ``obj`` shall be an instance of
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not an instance of ``cls``.
        """
        return _TestCase.assert_is_instance(obj=obj, cls=cls, message=message)

    @staticmethod
    def assert_is_none(obj: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``obj`` is ``None``.

        Args:
            obj: an object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not ``None``
        """
        return _TestCase.assert_is_none(obj=obj, message=message)

    @staticmethod
    def assert_is_not(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``id(a)`` does not equal ``id(b)``.

        Args:
            a: an object
            b: another object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``id(a)`` equals ``id(b)``
        """
        return _TestCase.assert_is_not(a=a, b=b, message=message)

    @staticmethod
    def assert_is_not_none(obj: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``obj`` is not ``None``.

        Args:
            obj: an object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is  ``None``
        """
        return _TestCase.assert_is_not_none(obj=obj, message=message)

    @staticmethod
    def assert_less(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` is less than ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not less than ``b``
        """
        return _TestCase.assert_less(a=a, b=b, message=message)

    @staticmethod
    def assert_less_equal(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` is less or equal to ``b``.

        Args:
            a: a comparable object
            b: a comparable object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` is not less or equal to ``b``
        """
        return _TestCase.assert_less_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_list_equal(a: List, b: List, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are of type ``list``.

        Args:
            a: a list
            b: a list
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_list_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_multi_line_equal(a: str, b: str, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are of type ``str``.

        Args:
            a: a string
            b: a string
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_multi_line_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_not_almost_equal(
        a: float,
        b: float,
        places: Optional[int] = None,
        delta: Optional[float] = None,
        message: Optional[str] = None,
    ) -> None:
        """
        Assert that ``a`` and ``b`` are not almost equal. Useful to compare floating point numbers.
        Comparison is realized either using a maximum ``delta`` or the number of decimal ``places``

        Args:
            a: number
            b: number
            places=None: the number of decimal places for comparison. If ``None`` ``7`` decimal places are used.
            delta=None: the maximum delta
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are almost equal.
        """
        return _TestCase.assert_not_almost_equal(a=a, b=b, places=places, delta=delta, message=message)

    @staticmethod
    def assert_not_equal(a: Any, b: Any, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` does not equal ``b``.

        Args:
            a: an object
            b: an object
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are equal.
        """
        return _TestCase.assert_not_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_not_in(member: Any, container: Iterable, message: Optional[str] = None) -> None:
        """
        Assert that ``container`` does not contain ``member``.

        Args:
            member: the object that shall not be included in ``container``
            container: an iterable to search for ``member``
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``member`` is included in ``container``
        """
        return _TestCase.assert_not_in(member=member, container=container, message=message)

    @staticmethod
    def assert_not_is_instance(obj: Any, cls: Type, message: Optional[str] = None) -> None:
        """
        Assert that ``obj`` is an instance of ``cls``.

        Args:
            obj: an instance
            cls: a class ``obj`` shall be an instance of
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``obj`` is not an instance of ``cls``.
        """
        return _TestCase.assert_not_is_instance(obj=obj, cls=cls, message=message)

    assert_is_not_instance = assert_not_is_instance

    @staticmethod
    def assert_not_regex(text: str, unexpected_regex: str, message: Optional[str] = None) -> None:
        """
        Assert that ``text`` does not match regular expression ``unexpected_regex``.

        Args:
            text: a text to be matched
            unexpected_regex: a regular expression to be used
            message=None: the message to prepend to the error message

            Raises:
                AssertionError: if ``text`` matches regular expression ``unexpected_regex``.
        """
        return _TestCase.assert_not_regex(text=text, unexpected_regex=unexpected_regex, message=message)

    @staticmethod
    def assert_raises(
        expected_exception: Type[BaseException], callable_object: Optional[Any] = None, *args: Any, **kwargs: Any
    ) -> Optional[_AssertRaisesContext]:
        """
        Assert that ``expected_exception`` is raised. Can be used as a context manager or
        with a callable object that is run with ``*args`` and ``**kwargs``.

        Args:
            expected_exception: the expected exception that shall be raised
            callable_object=None: the callable object if not used as a context manager
            *args: variable positional arguments passed to ``callable_object``
            **kwargs: variable keyword arguments passed to ``callable_object``

        Returns:
            a context manager if ``callable_object`` is ``None`` else ``None``.
        """
        return _TestCase.assert_raises(expected_exception, callable_object, *args, **kwargs)

    @staticmethod
    def assert_raises_regex(
        expected_exception: Type[BaseException],
        expected_regex: str,
        callable_object: Optional[Any] = None,
        *args: Any,
        **kwargs: Any
    ) -> Optional[_AssertRaisesContext]:
        """
        Assert that ``expected_exception`` is raised. Can be used as a context manager or
        with a callable object that is run with ``*args`` and ``**kwargs``.

        Args:
            expected_exception: the expected exception that shall be raised
            expected_regex: the regular expression that shall match the stringified representation
                of the exception
            callable_object=None: the callable object if not used as a context manager
            *args: variable positional arguments passed to ``callable_object``
            **kwargs: variable keyword arguments passed to ``callable_object``

        Returns:
            a context manager if ``callable_object`` is ``None`` else ``None``.
        """
        return _TestCase.assert_raises_regex(expected_exception, expected_regex, callable_object, *args, **kwargs)

    @staticmethod
    def assert_regex(text: str, expected_regex: str, message: Optional[str] = None) -> None:
        """
        Assert that ``text`` matches regular expression ``expected_regex``.

        Args:
            text: a text to be matched
            expected_regex: a regular expression to be used
            message=None: the message to prepend to the error message

            Raises:
                AssertionError: if ``text`` does not match regular expression ``expected_regex``.
        """
        return _TestCase.assert_regex(text=text, expected_regex=expected_regex, message=message)

    @staticmethod
    def assert_sequence_equal(  # noqa: C901: complexity accepted and well tested
        a: Sequence, b: Sequence, message: Optional[str] = None, sequence_type: Optional[Type] = None
    ) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are sequences.

        Args:
            a: a sequence
            b: a sequence
            sequence_type=None: the sequence type to be used (if not ``None``)
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_sequence_equal(a=a, b=b, message=message, sequence_type=sequence_type)

    @staticmethod
    def assert_set_equal(a: Set, b: Set, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are of type ``set``.

        Args:
            a: a set
            b: a set
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_set_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_str_equal(a: str, b: str, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are of type ``str``.

        Args:
            a: a string
            b: a string
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_str_equal(a=a, b=b, message=message)

    @staticmethod
    def assert_true(expression: bool, message: Optional[str] = None) -> None:
        """
        Assert that ``expression`` is ``True``.

        Args:
            expression: the boolean expression to be validated
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``expression`` is not ``True``
        """
        return _TestCase.assert_true(expression=expression, message=message)

    @staticmethod
    def assert_tuple_equal(a: Tuple, b: Tuple, message: Optional[str] = None) -> None:
        """
        Assert that ``a`` equals ``b`` and that both are of type ``tuple``.

        Args:
            a: a list
            b: a list
            message=None: the message to prepend to the error message

        Raises:
            AssertionError: if ``a`` and ``b`` are not equal.
        """
        return _TestCase.assert_tuple_equal(a=a, b=b, message=message)

    def attach_file(self, filename: str, title: str) -> None:
        """
        Attach a file to the current test that is put into
        the test report.

        Args:
            filename: the filename to be attached
            title: the title
        """
        return super(TestCase, self).attach_file(filename=filename, title=title)

    def attach_url(self, url: str, title: str) -> None:
        """
        Attach an url to the current test that is put into the test report.
        This results in an external link and should be used for huge files.

        Args:
            url: the url to be attached
            title: the title
        """
        return super(TestCase, self).attach_url(url=url, title=title)

    def delay(self, duration: float) -> None:
        """
        Delay execution for a given duration and print progress.

        Args:
            duration: sleep duration
        """
        return super(TestCase, self).delay(duration=duration)

    async def sleep(self, duration: float) -> None:
        """
        Delay execution (async) for a given duration and print progress.

        Args:
            duration: sleep duration
        """
        return await super(TestCase, self).sleep(duration=duration)

    def expect(self, expected_value: Any, observed_value: Any, error_message: Optional[str] = None) -> None:
        """
        Expect that ``expectedValue`` and ``observedValue`` are the same.
        If ``expectedValue`` and ``observedValue`` differ an ``AssertionError``
        is raised.

        Args:
            expected_value: the expected value.
            observed_value: the observed value that is compared to
                ``expectedValue``.
            errorMessage=None: an optional message.
        """
        return super(TestCase, self).expect(
            expected_value=expected_value, observed_value=observed_value, error_message=error_message
        )

    def expect_step(
        self, title: str, expected_value: Any, observed_value: Any, error_message: Optional[str] = None
    ) -> None:
        """
        Creates a test step in test report and on stdout using ``title``.
        Expect that `expectedValue` and `observedValue` are the same.
        If ``expectedValue`` and ``observedValue`` differ an ``AssertionError``
        is raised.

        Args:
            title: the step's title.
            expected_value: the value that is expected.
            observed_value: the current observed value that is compared to
                ``expectedValue``.
            errorMessage=None: an optional message.
        """
        return super(TestCase, self).expect_step(
            title=title, expected_value=expected_value, observed_value=observed_value, error_message=error_message
        )

    def run_background(
        self,
        func: Callable[..., Any],
        name: Optional[str] = None,
        stop: Optional[Callable[..., bool]] = None,
        force_stop: bool = True,
        join_timeout: float = 1.0,
        args: Optional[Tuple[Any]] = None,
        kwargs: Optional[Dict[str, Any]] = None,
    ) -> Callable[[], None]:
        """
        With this method you can run another method in background.

        Args:
            func: the method to be run in background.
            name=None: a name for the background task.
                Default: ``None``. If `name` is ``None`` `func.__name__` is
                used.
            stop=None: callable to stop the thread
            force_stop=True: force the thread to stop when leaving its scope (can impact performance)
            join_timeout=1: the timeout to be used when calling ``join``
                on the thread.
            args=None: a tuple of positional arguments that are passed
                to the background task when it is called.
            kwargs=None: a dictionary of keyword arguments that are
                passed to the background task when it is called.

        Returns:
            stop-trigger: a callable object is returned that stops
                execution when called.
        """
        return super(TestCase, self).run_background(
            func=func, name=name, stop=stop, force_stop=force_stop, join_timeout=join_timeout, args=args, kwargs=kwargs
        )

    def run_periodic(
        self,
        func: Callable[..., Any],
        period: float,
        maximum_period: Optional[float] = None,
        name: Optional[str] = None,
        raise_exception: bool = True,
        args: Optional[Tuple[Any]] = None,
        kwargs: Optional[Dict[str, Any]] = None,
    ) -> Callable[[], None]:
        """
        With this method you can run another method periodically
        in background with a given period.

        Args:
            func: the method to be called periodically in
                background.
            period: the period in second.
            maximum_period=None: if set to a float >= ``period``
                ``func`` may take up to ``maximum_period`` time without
                raising an exception. A warning is printed out to stdout
                instead.
            name=None: a name for the background task.
            raise_exceptions=True: if set to ``True`` exceptions are put into
                the exception queue to let a test fail if a background thread
                fails.
            args=None: a tuple of positional arguments that are passed
                to the background task when it is called.
            kwargs=None: a dictionary of keyword arguments that are
                passed to the background task when it is called.

        Returns:
            stop-trigger: a callable object is returned that stops
                execution when called.
        """
        return super(TestCase, self).run_periodic(
            func=func,
            period=period,
            maximum_period=maximum_period,
            name=name,
            raise_exception=raise_exception,
            args=args,
            kwargs=kwargs,
        )

    def set_up(self) -> None:
        """
        This method is called from test runner before a test is executed to
        create the test-fixtures.
        """
        return super(TestCase, self).set_up()

    @classmethod
    def set_up_class(cls) -> None:
        """
        This method is called for each class instance.
        """
        return super(TestCase, cls).set_up_class()

    def set_metadata(self, name: str, value: Any) -> None:
        """
        Set metadata for a running test.

        Args:
            name: the name of the metadata
            value: the value of the metadata
                (``value`` is casted to a string automatically)

        Raises:
            AssertionError: if ``name`` was already set to non accidentally overwrite
                existing metadata
        """
        return super(TestCase, self).set_metadata(name=name, value=value)

    def set_output_capture_enable(self, enabled: bool = True) -> None:
        """
        Enables or disables capturing of stdout and stderr for later
        use in test reports.

        Args:
            enabled=True: the new enabled state
        """
        return super(TestCase, self).set_output_capture_enable(enabled=enabled)

    def skip_step(self, message: str) -> None:
        """
        Skip the current test step.
        """
        return super(TestCase, self).skip_step(message=message)

    def skip_test(self, message: str) -> None:
        """
        Skip the current test.
        """
        return super(TestCase, self).skip_test(message=message)

    def step(self, title: str, *args: Any, **kwargs: Any) -> TestStep:
        """
        Run a test step that is documented in the test report.

        Args:
            title: the step's title.
            *args: a tuple of positional arguments for the step's
                context.
            **kwargs: a dictionary of keyword arguments for the step's
                context.
        """
        return super(TestCase, self).step(title, *args, **kwargs)  # type: ignore

    def stop_thread(self, name_or_function: Union[str, Callable]) -> int:
        """
        This method stops a specific thread with the name or
        function described by ``name_or_function`` by calling
        :func:`~htf.Thread.join` with join timeout supplied
        by :func:`~htf.fixtures.threads.run_periodic` or
        :func:`~htf.fixtures.threads.run_background` or on it.
        It does not set a stop condition so the thread must end and must
        not include an endless loop.
        If the thread is still alive after the first join messages are
        printed to inform the user.

        Args:
            name_or_function: the name or the function
                (reference) of the thread to be stopped.

        Returns:
            int: the number of stopped threads.

        Raises:
            Exception: if the thread was not found
        """
        return super(TestCase, self).stop_thread(name_or_function=name_or_function)

    def tear_down(self) -> None:
        """
        This method is called from test runner after a test was executed
        regardless of its result.

        This method shall destroy all used fixtures.
        """
        return super(TestCase, self).tear_down()

    @classmethod
    def tear_down_class(cls) -> None:
        """
        This method is called for each class instance.
        """
        return super(TestCase, cls).tear_down_class()
