#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from typing import Optional, Any, Callable, Tuple, Dict
from htf.core import Thread as _Thread


class Thread(_Thread):
    """
    ``Thread`` extends :class:`threading.Thread` to have a possibility to traceback where it was started.
    """

    def __init__(
        self,
        group: None = None,
        target: Optional[Callable[..., Any]] = None,
        name: Optional[str] = None,
        stop: Optional[Callable[..., bool]] = None,
        force_stop: bool = True,
        args: Optional[Tuple[Any]] = None,
        kwargs: Optional[Dict[str, Any]] = None,
    ) -> None:
        """
        This constructor should always be called with keyword arguments. Arguments are:

        *group* should be None; reserved for future extension when a ThreadGroup
        class is implemented.

        *target* is the callable object to be invoked by the run()
        method. Defaults to None, meaning nothing is called.

        *name* is the thread name. By default, a unique name is constructed of
        the form "Thread-N" where N is a small decimal number.

        *args* is the argument tuple for the target invocation. Defaults to ().

        *kwargs* is a dictionary of keyword arguments for the target
        invocation. Defaults to {}.

        If a subclass overrides the constructor, it must make sure to invoke
        the base class constructor (Thread.__init__()) before doing anything
        else to the thread.
        """
        super(Thread, self).__init__(
            group=group, target=target, name=name, stop=stop, force_stop=force_stop, args=args, kwargs=kwargs
        )

    def is_alive(self) -> bool:
        """
        Return whether the thread is alive.

        This method returns True just before the run() method starts until just
        after the run() method terminates. The module function enumerate()
        returns a list of all alive threads.
        """
        return super(Thread, self).is_alive()

    def join(self, timeout: Optional[float] = None) -> None:
        """
        Wait until the thread terminates.

        This blocks the calling thread until the thread whose join() method is
        called terminates -- either normally or through an unhandled exception
        or until the optional timeout occurs.

        When the timeout argument is present and not None, it should be a
        floating point number specifying a timeout for the operation in seconds
        (or fractions thereof). As join() always returns None, you must call
        is_alive() after join() to decide whether a timeout happened -- if the
        thread is still alive, the join() call timed out.

        When the timeout argument is not present or None, the operation will
        block until the thread terminates.

        A thread can be join()ed many times.

        join() raises a RuntimeError if an attempt is made to join the current
        thread as that would cause a deadlock. It is also an error to join() a
        thread before it has been started and attempts to do so raises the same
        exception.
        """
        super(Thread, self).join(timeout=timeout)

    def run(self) -> None:  # pragma: no cover
        """
        Method representing the thread's activity.

        You may override this method in a subclass. The standard run() method
        invokes the callable object passed to the object's constructor as the
        target argument, if any, with sequential and keyword arguments taken
        from the args and kwargs arguments, respectively.
        """
        super(Thread, self).run()

    def start(self) -> None:
        """
        Start the thread's activity.

        It must be called at most once per thread object. It arranges for the
        object's run() method to be invoked in a separate thread of control.

        This method will raise a RuntimeError if called more than once on the
        same thread object.
        """
        super(Thread, self).start()

    def stop(self) -> None:
        super(Thread, self).stop()
