#
# Copyright (c) 2024, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Tuple, Optional
import os
import re
import base64
import mimetypes


class HTMLEmbedder:
    def embed(self, html: str) -> str:
        directory = os.getcwd()
        data = self.replace_image(html, directory)

        return data

    @staticmethod
    def data_to_data_url(data: bytes, mimetype: Tuple[Optional[str], Optional[str]]) -> str:
        encoded = base64.b64encode(data)
        encoded_as_str = encoded.decode()
        data_url = "data:" + mimetype[0] + ";base64," + encoded_as_str  # type: ignore

        return data_url

    def url_to_data_url(self, url: str) -> str:
        """
        Create a data url guessing the mime-type and return the result.
        """
        if url.startswith("data:"):
            return url

        mimetype = mimetypes.guess_type(url)

        with open(url, "rb") as fp:
            data = fp.read()

        return self.data_to_data_url(data, mimetype)

    def replace_image(self, data: str, directory: str) -> str:
        """
        Replace all img tags that have a src-attribute
        and return the html document with all replacements.
        """
        img_tags = re.findall(r'(<\s*img\s+.*?\s+src="([^"]*)".*?>)', data, re.MULTILINE)

        for tag, src in img_tags:
            replacement = self.replace_img_src(src, directory)

            data = data.replace(src, replacement)

        return data

    def replace_img_src(self, src: str, directory: str) -> str:
        """
        Replace a single img with src-attribute using
        a data url and return the result as a tag that can be put
        into the original html document.
        """
        if src.startswith("data:"):
            return src

        # open file
        filename = os.path.join(directory, src)

        data_url = self.url_to_data_url(filename)

        return data_url
